==> v3.5.13.1.tar.gz: tdewebdev/kimagemapeditor/arealistview.h <==
/***************************************************************************
                          arealistview.h  -  description
                             -------------------
    begin                : Weg Feb 26 2003
    copyright            : (C) 2003 by Jan Schfer
    email                : janschaefer@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _AREALISTVIEW_H_
#define _AREALISTVIEW_H_

#include <tqwidget.h>
#include <tqvbox.h>

class KListView;
class TQPushButton;
class Area;

/**
 * This class consists of a ListView and two arrow buttons on the bottom.
 * It shows all Areas of the current map.
 * Jan Schaefer
 **/
class AreaListView : public TQVBox
{
  Q_OBJECT
  TQ_OBJECT

public:
  AreaListView(TQWidget *parent, const char *name);
  ~AreaListView();
  
  KListView* listView;
	TQPushButton *upBtn;
	TQPushButton *downBtn;
  
};

#endif

==> r14.0.13.tar.gz: tdewebdev/kimagemapeditor/arealistview.h <==
/***************************************************************************
                          arealistview.h  -  description
                             -------------------
    begin                : Weg Feb 26 2003
    copyright            : (C) 2003 by Jan Schfer
    email                : janschaefer@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _AREALISTVIEW_H_
#define _AREALISTVIEW_H_

#include <tqwidget.h>
#include <tqvbox.h>

class TDEListView;
class TQPushButton;
class Area;

/**
 * This class consists of a ListView and two arrow buttons on the bottom.
 * It shows all Areas of the current map.
 * Jan Schaefer
 **/
class AreaListView : public TQVBox
{
  Q_OBJECT
  

public:
  AreaListView(TQWidget *parent, const char *name);
  ~AreaListView();
  
  TDEListView* listView;
	TQPushButton *upBtn;
	TQPushButton *downBtn;
  
};

#endif
